@@ -1,5 +1,5 @@
 /*
- * Copyright © 2004, 2005, 2006, 2009 Guillem Jover
+ * Copyright © 2009 Guillem Jover
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -24,49 +24,12 @@
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef LIBBSD_CDEFS_H
-#define LIBBSD_CDEFS_H
+#ifndef LIBBSD_BSD_CDEFS_H
+#define LIBBSD_BSD_CDEFS_H
 
-#include <sys/cdefs.h>
+#warning "This header is deprecated, use the one in bsd/sys/cdefs.h instead."
 
-#ifndef setproctitle
-# define setproctitle(fmt, args...)
-#endif
-
-#ifndef __dead2
-# define __dead2
-#endif
-
-/* Linux headers define a struct with a member names __unused.
- * Disable for now. */
-#if 0
-#ifndef __unused
-# ifdef __GNUC__
-#  define __unused __attribute__((unused))
-# else
-#  define __unused
-# endif
-#endif
-#endif
-
-#ifndef __printflike
-# ifdef __GNUC__
-#  define __printflike(x, y) __attribute((format(printf, (x), (y))))
-# else
-#  define __printflike(x, y)
-# endif
-#endif
-
-#ifndef __bounded__
-# define __bounded__(x, y, z)
-#endif
-
-#ifndef __RCSID
-# define __RCSID(x)
-#endif
-
-#ifndef __FBSDID
-# define __FBSDID(x)
-#endif
+#include <bsd/sys/cdefs.h>
 
 #endif
+
