@@ -31,22 +31,30 @@
 
 #include <sys/cdefs.h>
 #include <sys/stat.h>
+#include <stdint.h>
 #include <stdlib.h>
 
+/* For compatibility with NetBSD, which defines humanize_number here. */
+#include <libutil.h>
+
+/* FIXME: Temporary inclusions to avoid API breakage, will be removed soon. */
+#include <bsd/stdio.h>
+#include <bsd/unistd.h>
+
 __BEGIN_DECLS
-const char *fmtcheck (const char *, const char *);
+u_int32_t arc4random();
+void arc4random_stir();
+void arc4random_addrandom(u_char *dat, int datlen);
+
+int dehumanize_number(const char *str, int64_t *size);
 
 char *getprogname ();
 void setprogname (char *);
 
 int heapsort (void *, size_t, size_t, int (*)(const void *, const void *));
 
-#ifndef S_ISTXT
-#define S_ISTXT S_ISVTX
-#endif
-
-mode_t getmode(const void *set, mode_t mode);
-void *setmode(const char *mode_str);
+long long strtonum(const char *nptr, long long minval, long long maxval,
+                   const char **errstr);
 __END_DECLS
 
 #endif
