@@ -29,13 +29,12 @@
 int optreset = 0;
 
 int
-bsd_getopt (int argc, char **argv, char *shortopts)
+bsd_getopt(int argc, char **argv, char *shortopts)
 {
-  if (optreset == 1)
-    {
-      optreset = 0;
-      optind = 0;
-    }
+	if (optreset == 1) {
+		optreset = 0;
+		optind = 0;
+	}
 
-  return getopt (argc, argv, shortopts);
+	return getopt(argc, argv, shortopts);
 }
